@@ -36,9 +36,9 @@
 
 
 /////////////////////// Qt includes
-#include <QDebug>
-#include <QMouseEvent>
-
+#include<QDebug>
+#include<QMouseEvent>
+#include<QMessageBox>
 
 /////////////////////// Local includes
 #include "globals.hpp"
@@ -69,8 +69,8 @@ namespace massXpert
 
 
     QHeaderView *headerView = horizontalHeader();
-    headerView->setClickable(true);
-    headerView->setMovable(true);
+    headerView->setSectionsClickable(true);
+    headerView->setSectionsMovable(true);
 
     ////// Create the actions for the contextual menu.
 
