@@ -35,10 +35,10 @@
 */
 
 /////////////////////// Qt includes
-#include <QDebug>
-#include <QHeaderView>
-#include <QMouseEvent>
-
+#include<QDebug>
+#include<QHeaderView>
+#include<QMouseEvent>
+#include<QMessageBox>
 
 /////////////////////// Local includes
 #include "globals.hpp"
@@ -68,8 +68,8 @@ namespace massXpert
 	     SLOT(itemActivated(const QModelIndex &)));  
 
     QHeaderView *headerView = horizontalHeader();
-    headerView->setClickable(true);
-    headerView->setMovable(true);
+    headerView->setSectionsClickable(true);
+    headerView->setSectionsMovable(true);
 
     ////// Create the actions for the contextual menu.
 
