@@ -72,8 +72,8 @@ namespace massXpert
     setDropIndicatorShown(true);
 
     QHeaderView *headerView = horizontalHeader();
-    headerView->setClickable(true);
-    headerView->setMovable(true);
+    headerView->setSectionsClickable(true);
+    headerView->setSectionsMovable(true);
 
     connect(this,
             SIGNAL(activated(const QModelIndex &)),
