@@ -620,7 +620,8 @@ namespace massXpert
             QModelIndex index =
               mpa_oligomerTableViewModel->index(count,
                                                 MZ_LAB_INPUT_OLIGO_MASS_COLUMN);
-            Q_ASSERT(index.isValid());
+            if(!index.isValid())
+              qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
 
             Oligomer *oligomer = m_oligomerList.at(count);
 
