@@ -478,7 +478,7 @@ namespace massXpert
 		qDebug() << __FILE__ << __LINE__ 
 			 << "First character of monomer code might not be"
 			 << "lower case; sequence is"
-			 << m_monomerText.toAscii();
+			 << m_monomerText;
 		
 		*err = curChar;
 	      
@@ -609,7 +609,7 @@ namespace massXpert
 	    // are certain that we won't have any chance to find the
 	    // sequence downstream of current index.
 	  
-	    matched = FALSE;
+	    matched = false;
 	    break;
 	  }
 
